@@ -19,19 +19,18 @@ Lingua::Conjunction - Convert lists into simple linguistic conjunctions
 
 =head1 VERSION
 
-Version 2.2
+Version 2.3
 
 =cut
 
-our $VERSION = '2.2';
+our $VERSION = '2.3';
 
 =head1 SYNOPSIS
 
-=encoding UTF-8
-
-Language-specific definitions (these may not be correct, and certainly
-they are not complete... E-mail corrections and additions to the author
-and an updated version will be released.)
+Language-specific definitions.
+These may not be correct, and certainly they are not complete.
+E-mail corrections and additions to C<< <njh at bandsman.co.uk> >>,
+and an updated version will be released.
 
 =cut
 
@@ -45,20 +44,20 @@ and an updated version will be released.)
 # dis = disjunction ("or"), well, grammatically still a "conjunction"...
 
 my %language = (
-    'af' => { sep => ',', alt => ";", pen => 1, con => 'en',  dis => 'of' },
-    'da' => { sep => ',', alt => ";", pen => 1, con => 'og',  dis => 'eller' },
-    'de' => { sep => ',', alt => ";", pen => 1, con => 'und', dis => 'oder' },
-    'en' => { sep => ',', alt => ";", pen => 1, con => 'and', dis => 'or' },
-    'es' => { sep => ',', alt => ";", pen => 1, con => 'y',   dis => 'o' },
-    'fi' => { sep => ',', alt => ";", pen => 1, con => 'ja',  dis => 'tai' },
-    'fr' => { sep => ',', alt => ";", pen => 0, con => 'et',  dis => 'ou' },
-    'id' => { sep => ',', alt => ";", pen => 1, con => 'dan', dis => 'atau' },
-    'it' => { sep => ',', alt => ";", pen => 1, con => 'e',   dis => 'o' },
-    'la' => { sep => ',', alt => ";", pen => 1, con => 'et',  dis => 'vel' },
-    'nl' => { sep => ',', alt => ';', pen => 1, con => 'en',  dis => 'of' },
-    'no' => { sep => ',', alt => ";", pen => 0, con => 'og',  dis => 'eller' },
-    'pt' => { sep => ',', alt => ";", pen => 1, con => 'e',   dis => 'ou' },
-    'sw' => { sep => ',', alt => ";", pen => 1, con => 'na',  dis => 'au' },
+	'af' => { sep => ',', alt => ';', pen => 1, con => 'en',  dis => 'of' },
+	'da' => { sep => ',', alt => ';', pen => 1, con => 'og',  dis => 'eller' },
+	'de' => { sep => ',', alt => ';', pen => 1, con => 'und', dis => 'oder' },
+	'en' => { sep => ',', alt => ';', pen => 1, con => 'and', dis => 'or' },
+	'es' => { sep => ',', alt => ';', pen => 1, con => 'y',   dis => 'o' },
+	'fi' => { sep => ',', alt => ';', pen => 1, con => 'ja',  dis => 'tai' },
+	'fr' => { sep => ',', alt => ';', pen => 0, con => 'et',  dis => 'ou' },
+	'id' => { sep => ',', alt => ';', pen => 1, con => 'dan', dis => 'atau' },
+	'it' => { sep => ',', alt => ';', pen => 1, con => 'e',   dis => 'o' },
+	'la' => { sep => ',', alt => ';', pen => 1, con => 'et',  dis => 'vel' },
+	'nl' => { sep => ',', alt => ';', pen => 1, con => 'en',  dis => 'of' },
+	'no' => { sep => ',', alt => ';', pen => 0, con => 'og',  dis => 'eller' },
+	'pt' => { sep => ',', alt => ';', pen => 1, con => 'e',   dis => 'ou' },
+	'sw' => { sep => ',', alt => ';', pen => 1, con => 'na',  dis => 'au' },
 );
 
 # Conjunction types. TODO: Someday we'll add either..or, neither..nor
@@ -111,24 +110,26 @@ You can also set connectives individually:
 =cut
 
 sub conjunction {
-    return $_[0] if @_ < 2;
-    return join " $punct{$list_type} ", @_ if @_ == 2;
+	# See List::ToHumanString
+	my @list = grep defined && /\S/, @_;
 
-    if ( $punct{pen} ) {
-        return join "$punct{sep} ", @_[ 0 .. $#_ - 1 ],
-          "$punct{$list_type} $_[-1]",
-          unless grep /$punct{sep}/, @_;
-        return join "$punct{alt} ", @_[ 0 .. $#_ - 1 ],
-          "$punct{$list_type} $_[-1]";
-    }
-    else {
-        return join "$punct{sep} ", @_[ 0 .. $#_ - 2 ],
-          "$_[-2] $punct{$list_type} $_[-1]",
-          unless grep /$punct{sep}/, @_;
-        return join "$punct{alt} ", @_[ 0 .. $#_ - 2 ],
-          "$_[-2] $punct{$list_type} $_[-1]";
-    }
+	return if(scalar(@list) == 0);
+	return $list[0] if(scalar(@list) == 1);
+	return join(" $punct{$list_type} ", @list) if(scalar(@list) == 2);
 
+	if ( $punct{pen} ) {
+		return join "$punct{sep} ", @list[ 0 .. $#_ - 1 ],
+		  "$punct{$list_type} $_[-1]",
+		  unless grep /$punct{sep}/, @list;
+		return join "$punct{alt} ", @list[ 0 .. $#_ - 1 ],
+		  "$punct{$list_type} $_[-1]";
+	} else {
+		return join "$punct{sep} ", @list[ 0 .. $#_ - 2 ],
+		  "$_[-2] $punct{$list_type} $_[-1]",
+		  unless grep /$punct{sep}/, @list;
+		return join "$punct{alt} ", @list[ 0 .. $#_ - 2 ],
+		  "$_[-2] $punct{$list_type} $_[-1]";
+	}
 }
 
 =head2 separator
@@ -290,7 +291,7 @@ Nigel Horne C<< <njh at bandsman.co.uk> >>
 
 =head1 SEE ALSO
 
-C<Locale::Language>
+C<Locale::Language>, C<List::ToHumanString>
 
 The I<Perl Cookbook> in Section 4.2 has a simular subroutine called
 C<commify_series>. The differences are that
@@ -341,7 +342,7 @@ L<http://deps.cpantesters.org/?module=Lingua::Conjunction>
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/nigelhorne/Lingua-Conjunction/issues>
+L<https://rt.cpan.org/Dist/Display.html?Queue=Lingua-Conjunction>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
